@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::DataComparisonModules::Compare;
 
-our $VERSION = 0.001; # VERSION
+our $VERSION = 0.002; # VERSION
 
 our $results = [
   [
@@ -9,138 +9,138 @@ our $results = [
     [
       {
         dataset     => "hash keys=1000",
-        errors      => 8.1e-06,
+        errors      => 1.6e-05,
         participant => "Data::Compare::Compare",
-        rate        => 210,
+        rate        => 220,
         samples     => 20,
-        time        => 4.8,
+        time        => 4.6,
         vs_slowest  => 1,
       },
       {
         dataset     => "array len=1000",
-        errors      => 4.7e-06,
+        errors      => 4.2e-06,
         participant => "Data::Compare::Compare",
-        rate        => 290,
-        samples     => 20,
-        time        => 3.5,
+        rate        => 300,
+        samples     => 21,
+        time        => 3.3,
         vs_slowest  => 1.4,
       },
       {
         dataset     => "hash keys=1000",
-        errors      => 5.8e-06,
+        errors      => 8.3e-06,
         participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 360,
+        rate        => 380,
         samples     => 20,
-        time        => 2.8,
-        vs_slowest  => 1.7,
+        time        => 2.6,
+        vs_slowest  => 1.8,
       },
       {
         dataset     => "hash keys=1000",
-        errors      => 3.3e-06,
+        errors      => 3.1e-06,
         participant => "Data::Cmp::cmp_data",
-        rate        => 620,
-        samples     => 21,
+        rate        => 640,
+        samples     => 20,
         time        => 1.6,
-        vs_slowest  => 3,
+        vs_slowest  => 2.9,
       },
       {
         dataset     => "array len=1000",
-        errors      => 2.7e-06,
+        errors      => 4.1e-06,
         participant => "Data::Cmp::cmp_data",
         rate        => 1000,
         samples     => 20,
-        time        => 0.99,
-        vs_slowest  => 4.8,
+        time        => 0.97,
+        vs_slowest  => 4.7,
       },
       {
         dataset     => "array len=1000",
-        errors      => 1.4e-06,
+        errors      => 2.2e-06,
         participant => "Test::Deep::NoTest::eq_deeply",
         rate        => 1400,
-        samples     => 26,
-        time        => 0.73,
+        samples     => 21,
+        time        => 0.69,
         vs_slowest  => 6.6,
       },
       {
         dataset     => "hash keys=10",
-        errors      => 2.1e-07,
+        errors      => 2.6e-07,
         participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 6100,
-        samples     => 20,
-        time        => 0.16,
-        vs_slowest  => 29,
+        rate        => 6500,
+        samples     => 21,
+        time        => 0.15,
+        vs_slowest  => 30,
       },
       {
         dataset     => "array len=10",
         errors      => 2.1e-07,
         participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 7800,
+        rate        => 8400,
         samples     => 20,
-        time        => 0.13,
-        vs_slowest  => 37,
+        time        => 0.12,
+        vs_slowest  => 38,
       },
       {
         dataset     => "hash keys=10",
-        errors      => 1.1e-07,
+        errors      => 9.5e-08,
         participant => "Data::Compare::Compare",
-        rate        => 18000,
-        samples     => 20,
-        time        => 0.057,
-        vs_slowest  => 84,
+        rate        => 17000,
+        samples     => 25,
+        time        => 0.058,
+        vs_slowest  => 80,
       },
       {
         dataset     => "array len=10",
         errors      => 1.3e-08,
         participant => "Data::Compare::Compare",
-        rate        => 24100,
+        rate        => 25600,
         samples     => 21,
-        time        => 0.0415,
-        vs_slowest  => 115,
+        time        => 0.039,
+        vs_slowest  => 118,
       },
       {
         dataset     => "hash keys=10",
-        errors      => 3.9e-11,
+        errors      => 2.7e-08,
         participant => "Data::Cmp::cmp_data",
-        rate        => 62105,
+        rate        => 64000,
         samples     => 20,
-        time        => 0.016102,
-        vs_slowest  => 297.87,
+        time        => 0.016,
+        vs_slowest  => 290,
       },
       {
         dataset     => "array len=10",
-        errors      => 2.3e-08,
+        errors      => 1.2e-08,
         participant => "Data::Cmp::cmp_data",
-        rate        => 79000,
-        samples     => 34,
-        time        => 0.013,
-        vs_slowest  => 380,
+        rate        => 87000,
+        samples     => 26,
+        time        => 0.012,
+        vs_slowest  => 400,
       },
       {
         dataset     => "simple scalar",
-        errors      => 0,
+        errors      => 1.7e-09,
         participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 157800,
-        samples     => 30,
-        time        => 0.00633715,
-        vs_slowest  => 756.835,
+        rate        => 174000,
+        samples     => 20,
+        time        => 0.00576,
+        vs_slowest  => 796,
       },
       {
         dataset     => "simple scalar",
-        errors      => 7e-09,
+        errors      => 2.8e-09,
         participant => "Data::Compare::Compare",
-        rate        => 410000,
-        samples     => 23,
-        time        => 0.0024,
+        rate        => 450000,
+        samples     => 28,
+        time        => 0.0022,
         vs_slowest  => 2000,
       },
       {
         dataset     => "simple scalar",
-        errors      => 4.4e-11,
+        errors      => 4.7e-09,
         participant => "Data::Cmp::cmp_data",
-        rate        => 1104000,
-        samples     => 25,
-        time        => 0.0009057,
-        vs_slowest  => 5296,
+        rate        => 1100000,
+        samples     => 23,
+        time        => 0.00087,
+        vs_slowest  => 5300,
       },
     ],
     {
@@ -265,7 +265,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2847.424,
+                                              speed                        => 2593.811,
                                               stepping                     => 4,
                                             },
                                             {
@@ -381,7 +381,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2791.625,
+                                              speed                        => 2472.644,
                                               stepping                     => 4,
                                             },
                                             {
@@ -497,7 +497,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2559.545,
+                                              speed                        => 2779.577,
                                               stepping                     => 4,
                                             },
                                             {
@@ -613,11 +613,11 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2729.162,
+                                              speed                        => 2588.598,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.700480937957764,
+      "func.elapsed_time"              => 0.657371044158936,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => 1.041,
@@ -657,13 +657,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::DataComparisonModules::Compare",
-      "func.scenario_module_md5sum"    => "e700d4238e821c86c136ac44b5c0513c",
-      "func.scenario_module_mtime"     => 1534032616,
-      "func.scenario_module_sha1sum"   => "aabe1d92d51298dc698803db9e687865ac5a14ba",
-      "func.scenario_module_sha256sum" => "e6f8880a0bcaf3da2a44f76c73536efb73c375b23b96e00b2358c9c2439e5a3e",
-      "func.time_end"                  => 1534032627.9865,
+      "func.scenario_module_md5sum"    => "af689f2d40a7985cb595419ef34a7bfd",
+      "func.scenario_module_mtime"     => 1534033084,
+      "func.scenario_module_sha1sum"   => "d1ba6929e617ba63df9915bbffe73d3d1173a8af",
+      "func.scenario_module_sha256sum" => "2ef1dd5ab4cb3174f25374b2c3f2c458233d9c452a8a8b4c2028b9dd08762508",
+      "func.time_end"                  => 1534033119.01409,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1534032627.28601,
+      "func.time_start"                => 1534033118.35671,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
